==> libwnck-0.10.tar.bz2: libwnck-0.10/libwnck/inlinepixbufs.h <==
/* GdkPixbuf RGBA C-Source image dump */

static const guint8 default_icon_data[] = 
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (2304) */
  "\0\0\11\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (96) */
  "\0\0\0`"
  /* width (24) */
  "\0\0\0\30"
  /* height (24) */
  "\0\0\0\30"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\340\340\340\377\301\301\301\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\375\375\375\377\373\373\373\377\372\372\371\377\303"
  "\303\303\377\373\373\373\377\250\250\250\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377"
  "\374\374\374\377\372\372\372\377\371\371\370\377\367\367\366\377\255"
  "\255\255\377vvv\377]]]\377@@@\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\376\376\376\377\374\374\374\377\373\373\372\377\371\371\371\377\367"
  "\367\367\377\366\366\365\377\364\364\364\377\342\342\342\377\205\205"
  "\205\377KKI\377\26\26\26\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\376\376\376\377\375\375\374\377\373"
  "\373\373\377\371\371\371\377\370\370\367\377\366\366\366\377\365\365"
  "\364\377\363\363\362\377\362\362\361\377\360\360\357\377\356\356\355"
  "\377\355\355\353\377\235\235\235\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\375\375\375\377\373\373\373\377\372\372\371"
  "\377\370\370\370\377\367\367\366\377\365\365\364\377\364\364\363\377"
  "\362\362\361\377\360\360\357\377\357\357\356\377\355\355\354\377\354"
  "\354\352\377\352\352\350\377\244\244\243\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\374\374\374\377\372\372\372\377\371\371\370\377\367"
  "\367\366\377\365\365\365\377\364\364\363\377\362\362\361\377\361\361"
  "\360\377\357\357\356\377\356\356\354\377\354\354\353\377\352\352\351"
  "\377\351\351\347\377\347\347\346\377\244\244\244\377\0\0\0\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\376\376\376\377\374\374"
  "\374\377\373\373\372\377\371\371\371\377\367\367\367\377\366\366\365"
  "\377\364\364\364\377\363\363\362\377\361\361\360\377\360\360\356\377"
  "\356\356\355\377\354\354\353\377\353\353\351\377\351\351\350\377\350"
  "\350\346\377\346\346\344\377\345\345\343\377\242\242\242\377\0\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\373\373\373\377\371"
  "\371\371\377\370\370\367\377\366\366\366\377\365\365\364\377\363\363"
  "\362\377\362\362\361\377\360\360\357\377\356\356\355\377\355\355\353"
  "\377\353\353\352\377\352\352\350\377\350\350\346\377\347\347\345\377"
  "\345\345\343\377\343\343\341\377\342\342\340\377\242\242\242\377\0\0"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\370\370\370"
  "\377\367\367\366\377\365\365\364\377\364\364\363\377\362\362\361\377"
  "\360\360\357\377\357\357\356\377\355\355\354\377\354\354\352\377\352"
  "\352\350\377\351\351\347\377\347\347\345\377\345\345\343\377\344\344"
  "\342\377\342\342\340\377\341\341\336\377\337\337\335\377\243\243\242"
  "\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\365"
  "\365\365\377\364\364\363\377\362\362\361\377\361\361\360\377\357\357"
  "\356\377\356\356\354\377\354\354\353\377\352\352\351\377\351\351\347"
  "\377\347\347\346\377\346\346\344\377\344\344\342\377\343\343\340\377"
  "\341\341\337\377\340\340\335\377\336\336\333\377\334\334\332\377\243"
  "\243\242\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377"
  "\377\363\363\362\377\361\361\360\377\360\360\356\377\356\356\355\377"
  "\354\354\353\377\353\353\351\377\351\351\350\377\350\350\346\377\346"
  "\346\344\377\345\345\343\377\343\343\341\377\341\341\337\377\340\340"
  "\336\377\336\336\334\377\335\335\332\377\333\333\330\377\332\332\327"
  "\377\240\240\237\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377"
  "\377\377\377\360\360\357\377\356\356\355\377\355\355\353\377\353\353"
  "\352\377\352\352\350\377\350\350\346\377\347\347\345\377\345\345\343"
  "\377\343\343\341\377\342\342\340\377\340\340\336\377\337\337\334\377"
  "\335\335\333\377\334\334\331\377\332\332\327\377\330\330\325\377\327"
  "\327\324\377\242\242\241\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\377\377\377\377\355\355\354\377\354\354\352\377\352\352\350\377"
  "\351\351\347\377\347\347\345\377\345\345\343\377\344\344\342\377\342"
  "\342\340\377\341\341\336\377\337\337\335\377\336\336\333\377\334\334"
  "\331\377\332\332\330\377\331\331\326\377\327\327\324\377\326\326\322"
  "\377\324\324\321\377\242\242\241\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\377\377\377\377\377\352\352\351\377\351\351\347\377\347\347"
  "\346\377\346\346\344\377\344\344\342\377\343\343\340\377\341\341\337"
  "\377\340\340\335\377\336\336\333\377\334\334\332\377\333\333\330\377"
  "\331\331\326\377\330\330\325\377\326\326\323\377\325\325\321\377\323"
  "\323\320\377\321\321\316\377\241\241\240\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\377\377\377\377\377\350\350\346\377\346\346\344\377"
  "\345\345\343\377\343\343\341\377\341\341\337\377\340\340\336\377\336"
  "\336\334\377\335\335\332\377\333\333\330\377\332\332\327\377\330\330"
  "\325\377\326\326\323\377\325\325\322\377\323\323\320\377\322\322\316"
  "\377\320\320\315\377\317\317\313\377\240\240\237\377\0\0\0\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\345\345\343\377\343\343"
  "\341\377\342\342\340\377\340\340\336\377\337\337\334\377\335\335\333"
  "\377\334\334\331\377\332\332\327\377\330\330\325\377\327\327\324\377"
  "\325\325\322\377\324\324\320\377\322\322\317\377\321\321\315\377\317"
  "\317\313\377\315\315\312\377\314\314\310\377\242\242\241\377\0\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\342\342\340\377\341"
  "\341\336\377\337\337\335\377\336\336\333\377\334\334\331\377\332\332"
  "\330\377\331\331\326\377\327\327\324\377\326\326\322\377\324\324\321"
  "\377\323\323\317\377\321\321\315\377\317\317\314\377\316\316\312\377"
  "\314\314\310\377\314\314\307\377\314\314\307\377\242\242\240\377\0\0"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\340\340\335"
  "\377\336\336\333\377\334\334\332\377\333\333\330\377\331\331\326\377"
  "\330\330\325\377\326\326\323\377\325\325\321\377\323\323\320\377\321"
  "\321\316\377\320\320\314\377\316\316\312\377\315\315\311\377\314\314"
  "\307\377\314\314\307\377\314\314\307\377\314\314\307\377\237\237\237"
  "\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\335"
  "\335\332\377\333\333\330\377\332\332\327\377\330\330\325\377\326\326"
  "\323\377\325\325\322\377\323\323\320\377\322\322\316\377\320\320\315"
  "\377\317\317\313\377\315\315\311\377\314\314\307\377\314\314\307\377"
  "\314\314\307\377\314\314\307\377\314\314\307\377\314\314\307\377\240"
  "\240\237\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\320\320\320"
  "\377\261\261\257\377\264\264\263\377\264\264\261\377\240\240\235\377"
  "\240\240\235\377\237\237\235\377\237\237\235\377\237\237\233\377\231"
  "\231\225\377\215\215\211\377\213\213\211\377\213\213\211\377\213\213"
  "\211\377\211\211\211\377\211\211\211\377\203\203\177\377\204\204\202"
  "\377]]\\\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0r\0\0\0\0"};

==> libwnck-0.12.tar.bz2: libwnck-0.12/libwnck/inlinepixbufs.h <==
/* GdkPixbuf RGBA C-Source image dump */

static const guint8 default_icon_data[] = 
( ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (2304) */
  "\0\0\11\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (96) */
  "\0\0\0`"
  /* width (24) */
  "\0\0\0\30"
  /* height (24) */
  "\0\0\0\30"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\340\340\340\377\301\301\301\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\375\375\375\377\373\373\373\377\372\372\371\377\303"
  "\303\303\377\373\373\373\377\250\250\250\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377"
  "\374\374\374\377\372\372\372\377\371\371\370\377\367\367\366\377\255"
  "\255\255\377vvv\377]]]\377@@@\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\376\376\376\377\374\374\374\377\373\373\372\377\371\371\371\377\367"
  "\367\367\377\366\366\365\377\364\364\364\377\342\342\342\377\205\205"
  "\205\377KKI\377\26\26\26\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\376\376\376\377\375\375\374\377\373"
  "\373\373\377\371\371\371\377\370\370\367\377\366\366\366\377\365\365"
  "\364\377\363\363\362\377\362\362\361\377\360\360\357\377\356\356\355"
  "\377\355\355\353\377\235\235\235\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\375\375\375\377\373\373\373\377\372\372\371"
  "\377\370\370\370\377\367\367\366\377\365\365\364\377\364\364\363\377"
  "\362\362\361\377\360\360\357\377\357\357\356\377\355\355\354\377\354"
  "\354\352\377\352\352\350\377\244\244\243\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\374\374\374\377\372\372\372\377\371\371\370\377\367"
  "\367\366\377\365\365\365\377\364\364\363\377\362\362\361\377\361\361"
  "\360\377\357\357\356\377\356\356\354\377\354\354\353\377\352\352\351"
  "\377\351\351\347\377\347\347\346\377\244\244\244\377\0\0\0\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\376\376\376\377\374\374"
  "\374\377\373\373\372\377\371\371\371\377\367\367\367\377\366\366\365"
  "\377\364\364\364\377\363\363\362\377\361\361\360\377\360\360\356\377"
  "\356\356\355\377\354\354\353\377\353\353\351\377\351\351\350\377\350"
  "\350\346\377\346\346\344\377\345\345\343\377\242\242\242\377\0\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\373\373\373\377\371"
  "\371\371\377\370\370\367\377\366\366\366\377\365\365\364\377\363\363"
  "\362\377\362\362\361\377\360\360\357\377\356\356\355\377\355\355\353"
  "\377\353\353\352\377\352\352\350\377\350\350\346\377\347\347\345\377"
  "\345\345\343\377\343\343\341\377\342\342\340\377\242\242\242\377\0\0"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\370\370\370"
  "\377\367\367\366\377\365\365\364\377\364\364\363\377\362\362\361\377"
  "\360\360\357\377\357\357\356\377\355\355\354\377\354\354\352\377\352"
  "\352\350\377\351\351\347\377\347\347\345\377\345\345\343\377\344\344"
  "\342\377\342\342\340\377\341\341\336\377\337\337\335\377\243\243\242"
  "\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\365"
  "\365\365\377\364\364\363\377\362\362\361\377\361\361\360\377\357\357"
  "\356\377\356\356\354\377\354\354\353\377\352\352\351\377\351\351\347"
  "\377\347\347\346\377\346\346\344\377\344\344\342\377\343\343\340\377"
  "\341\341\337\377\340\340\335\377\336\336\333\377\334\334\332\377\243"
  "\243\242\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377"
  "\377\363\363\362\377\361\361\360\377\360\360\356\377\356\356\355\377"
  "\354\354\353\377\353\353\351\377\351\351\350\377\350\350\346\377\346"
  "\346\344\377\345\345\343\377\343\343\341\377\341\341\337\377\340\340"
  "\336\377\336\336\334\377\335\335\332\377\333\333\330\377\332\332\327"
  "\377\240\240\237\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377"
  "\377\377\377\360\360\357\377\356\356\355\377\355\355\353\377\353\353"
  "\352\377\352\352\350\377\350\350\346\377\347\347\345\377\345\345\343"
  "\377\343\343\341\377\342\342\340\377\340\340\336\377\337\337\334\377"
  "\335\335\333\377\334\334\331\377\332\332\327\377\330\330\325\377\327"
  "\327\324\377\242\242\241\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\377\377\377\377\355\355\354\377\354\354\352\377\352\352\350\377"
  "\351\351\347\377\347\347\345\377\345\345\343\377\344\344\342\377\342"
  "\342\340\377\341\341\336\377\337\337\335\377\336\336\333\377\334\334"
  "\331\377\332\332\330\377\331\331\326\377\327\327\324\377\326\326\322"
  "\377\324\324\321\377\242\242\241\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\377\377\377\377\377\352\352\351\377\351\351\347\377\347\347"
  "\346\377\346\346\344\377\344\344\342\377\343\343\340\377\341\341\337"
  "\377\340\340\335\377\336\336\333\377\334\334\332\377\333\333\330\377"
  "\331\331\326\377\330\330\325\377\326\326\323\377\325\325\321\377\323"
  "\323\320\377\321\321\316\377\241\241\240\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\377\377\377\377\377\350\350\346\377\346\346\344\377"
  "\345\345\343\377\343\343\341\377\341\341\337\377\340\340\336\377\336"
  "\336\334\377\335\335\332\377\333\333\330\377\332\332\327\377\330\330"
  "\325\377\326\326\323\377\325\325\322\377\323\323\320\377\322\322\316"
  "\377\320\320\315\377\317\317\313\377\240\240\237\377\0\0\0\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\345\345\343\377\343\343"
  "\341\377\342\342\340\377\340\340\336\377\337\337\334\377\335\335\333"
  "\377\334\334\331\377\332\332\327\377\330\330\325\377\327\327\324\377"
  "\325\325\322\377\324\324\320\377\322\322\317\377\321\321\315\377\317"
  "\317\313\377\315\315\312\377\314\314\310\377\242\242\241\377\0\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\342\342\340\377\341"
  "\341\336\377\337\337\335\377\336\336\333\377\334\334\331\377\332\332"
  "\330\377\331\331\326\377\327\327\324\377\326\326\322\377\324\324\321"
  "\377\323\323\317\377\321\321\315\377\317\317\314\377\316\316\312\377"
  "\314\314\310\377\314\314\307\377\314\314\307\377\242\242\240\377\0\0"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\340\340\335"
  "\377\336\336\333\377\334\334\332\377\333\333\330\377\331\331\326\377"
  "\330\330\325\377\326\326\323\377\325\325\321\377\323\323\320\377\321"
  "\321\316\377\320\320\314\377\316\316\312\377\315\315\311\377\314\314"
  "\307\377\314\314\307\377\314\314\307\377\314\314\307\377\237\237\237"
  "\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\335"
  "\335\332\377\333\333\330\377\332\332\327\377\330\330\325\377\326\326"
  "\323\377\325\325\322\377\323\323\320\377\322\322\316\377\320\320\315"
  "\377\317\317\313\377\315\315\311\377\314\314\307\377\314\314\307\377"
  "\314\314\307\377\314\314\307\377\314\314\307\377\314\314\307\377\240"
  "\240\237\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\320\320\320"
  "\377\261\261\257\377\264\264\263\377\264\264\261\377\240\240\235\377"
  "\240\240\235\377\237\237\235\377\237\237\235\377\237\237\233\377\231"
  "\231\225\377\215\215\211\377\213\213\211\377\213\213\211\377\213\213"
  "\211\377\211\211\211\377\211\211\211\377\203\203\177\377\204\204\202"
  "\377]]\\\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0r\0\0\0\0");
